/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.skywalking.oap.server.webapp;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class Configuration {
  private String serverPort;
  private String oapServices;
  private String zipkinServices;

  public int port() {
    return serverPort == null || serverPort.trim().length() == 0
      ? 80
      : Integer.parseInt(serverPort);
  }

  public String[] oapServices() {
    if (oapServices == null || oapServices.trim().length() == 0) {
      throw new IllegalArgumentException("oapServices cannot be null or empty");
    }
    return oapServices.split(",");
  }

  public String[] zipkinServices() {
    if (zipkinServices == null || zipkinServices.trim().length() == 0) {
      throw new IllegalArgumentException("zipkinServices cannot be null or empty");
    }
    return zipkinServices.split(",");
  }
}
